extern "C" int func();

class BreakPlainCCompiler;

int main(void) {
    return func();
}
